@@ -1,3 +1,6 @@
+# Copyright (c) Acconeer AB, 2022
+# All rights reserved
+
 from __future__ import annotations
 
 import logging
@@ -40,6 +43,7 @@ from acconeer.exptool.app.new.ui.plugin import (
     GridGroupBox,
     PidgetFactoryMapping,
     pidgets,
+    utils,
 )
 
 from ._detector import (
@@ -59,6 +63,7 @@ log = logging.getLogger(__name__)
 
 @attrs.mutable(kw_only=True)
 class SharedState:
+    sensor_id: int = attrs.field(default=1)
     config: DetectorConfig = attrs.field(factory=DetectorConfig)
     context: DetectorContext = attrs.field(factory=DetectorContext)
     replaying: bool = attrs.field(default=False)
@@ -150,6 +155,11 @@ class BackendPlugin(DetectorBackendPluginBase[SharedState]):
         self.shared_state.config = config
         self.broadcast()
 
+    @is_task
+    def update_sensor_id(self, *, sensor_id: int) -> None:
+        self.shared_state.sensor_id = sensor_id
+        self.broadcast()
+
     def teardown(self) -> None:
         self.callback(
             GeneralMessage(
@@ -175,10 +185,10 @@ class BackendPlugin(DetectorBackendPluginBase[SharedState]):
             self.callback(PluginStateMessage(state=PluginState.LOADED_IDLE))
             raise HandledException("Could not load from file") from exc
 
-        self.start_session(with_recorder=False)
-
         self.shared_state.replaying = True
 
+        self.start_session(with_recorder=False)
+
         self.send_status_message(f"<b>Replaying from {path.name}</b>")
         self.broadcast(sync=True)
 
@@ -206,7 +216,7 @@ class BackendPlugin(DetectorBackendPluginBase[SharedState]):
 
         self._detector_instance = Detector(
             client=self._client,
-            sensor_id=1,
+            sensor_id=self.shared_state.sensor_id,
             detector_config=self.shared_state.config,
             context=self.shared_state.context,
         )
@@ -217,7 +227,9 @@ class BackendPlugin(DetectorBackendPluginBase[SharedState]):
             self._recorder = None
 
         try:
-            self._detector_instance.start(self._recorder)
+            self._detector_instance.start(
+                self._recorder, skip_calibration=self.shared_state.replaying
+            )
         except Exception as exc:
             self.callback(PluginStateMessage(state=PluginState.LOADED_IDLE))
             raise HandledException("Could not start") from exc
@@ -311,7 +323,7 @@ class BackendPlugin(DetectorBackendPluginBase[SharedState]):
         try:
             self._detector_instance = Detector(
                 client=self._client,
-                sensor_id=1,
+                sensor_id=self.shared_state.sensor_id,
                 detector_config=self.shared_state.config,
                 context=self.shared_state.context,
             )
@@ -340,7 +352,7 @@ class BackendPlugin(DetectorBackendPluginBase[SharedState]):
         try:
             self._detector_instance = Detector(
                 client=self._client,
-                sensor_id=1,
+                sensor_id=self.shared_state.sensor_id,
                 detector_config=self.shared_state.config,
                 context=self.shared_state.context,
             )
@@ -460,6 +472,14 @@ class ViewPlugin(DetectorViewPluginBase):
             "Configuration does not match configuration"
             + " used during recorded threshold calibration. Please rerun calibration."
         ),
+        DetailedStatus.INVALID_DETECTOR_CONFIG_RANGE: (
+            "Invalid detector config. Valid measurement"
+            + " range is "
+            + str(Detector.MIN_DIST_M)
+            + "-"
+            + str(Detector.MAX_DIST_M)
+            + "m."
+        ),
     }
 
     def __init__(self, app_model: AppModel, view_widget: QWidget) -> None:
@@ -476,12 +496,15 @@ class ViewPlugin(DetectorViewPluginBase):
             "Start measurement",
             self.view_widget,
         )
+        self.start_button.setShortcut("space")
         self.start_button.clicked.connect(self._send_start_request)
+
         self.stop_button = QPushButton(
             qta.icon("fa5s.stop-circle", color=BUTTON_ICON_COLOR),
             "Stop",
             self.view_widget,
         )
+        self.stop_button.setShortcut("space")
         self.stop_button.clicked.connect(self._send_stop_request)
 
         self.record_threshold_button = QPushButton(
@@ -517,6 +540,16 @@ class ViewPlugin(DetectorViewPluginBase):
         button_group.layout().addWidget(self.message_box, 3, 0, 1, -1)
         self.view_layout.addWidget(button_group)
 
+        sensor_selection_group = utils.VerticalGroupBox(
+            "Sensor selection", parent=self.view_widget
+        )
+        self.sensor_id_pidget = pidgets.SensorIdParameterWidgetFactory(items=[]).create(
+            parent=sensor_selection_group
+        )
+        self.sensor_id_pidget.sig_parameter_changed.connect(self._on_sensor_id_update)
+        sensor_selection_group.layout().addWidget(self.sensor_id_pidget)
+        self.view_layout.addWidget(sensor_selection_group)
+
         self.config_editor = AttrsConfigEditor[DetectorConfig](
             title="Detector parameters",
             factory_mapping=self._get_pidget_mapping(),
@@ -593,7 +626,7 @@ class ViewPlugin(DetectorViewPluginBase):
             "signal_quality": pidgets.FloatSliderParameterWidgetFactory(
                 name_label_text="Signal quality",
                 decimals=1,
-                limits=(-2, 38),
+                limits=(5, 25),
                 show_limit_values=False,
                 limit_texts=("Less power", "Higher quality"),
             ),
@@ -604,6 +637,7 @@ class ViewPlugin(DetectorViewPluginBase):
 
     def on_app_model_update(self, app_model: AppModel) -> None:
         state = app_model.backend_plugin_state
+        self.sensor_id_pidget.update_available_sensor_list(app_model._a121_server_info)
 
         if state is None:
             self.start_button.setEnabled(False)
@@ -614,6 +648,7 @@ class ViewPlugin(DetectorViewPluginBase):
 
             self.config_editor.set_data(None)
             self.config_editor.setEnabled(False)
+            self.sensor_id_pidget.set_parameter(None)
             self.message_box.setText("")
 
             return
@@ -624,6 +659,8 @@ class ViewPlugin(DetectorViewPluginBase):
 
         self.config_editor.setEnabled(app_model.plugin_state == PluginState.LOADED_IDLE)
         self.config_editor.set_data(state.config)
+        self.sensor_id_pidget.set_parameter(state.sensor_id)
+        self.sensor_id_pidget.setEnabled(app_model.plugin_state.is_steady)
 
         detector_status = Detector.get_detector_status(state.config, state.context)
 
@@ -643,6 +680,9 @@ class ViewPlugin(DetectorViewPluginBase):
         self.start_button.setEnabled(ready_for_session and detector_status.ready_to_start)
         self.stop_button.setEnabled(app_model.plugin_state == PluginState.LOADED_BUSY)
 
+    def _on_sensor_id_update(self, sensor_id: int) -> None:
+        self.app_model.put_backend_plugin_task("update_sensor_id", {"sensor_id": sensor_id})
+
     # TODO: move to detector base (?)
     def _on_config_update(self, config: DetectorConfig) -> None:
         self.app_model.put_backend_plugin_task("update_config", {"config": config})
