@@ -1,3 +1,6 @@
+# Copyright (c) Acconeer AB, 2022
+# All rights reserved
+
 from __future__ import annotations
 
 import logging
@@ -40,6 +43,7 @@ from acconeer.exptool.app.new.ui.plugin import (
     GridGroupBox,
     PidgetFactoryMapping,
     pidgets,
+    utils,
 )
 
 from ._detector import Detector, DetectorConfig, DetectorResult, _load_algo_data
@@ -50,6 +54,7 @@ log = logging.getLogger(__name__)
 
 @attrs.mutable(kw_only=True)
 class SharedState:
+    sensor_id: int = attrs.field(default=1)
     config: DetectorConfig = attrs.field(factory=DetectorConfig)
     replaying: bool = attrs.field(default=False)
 
@@ -106,6 +111,11 @@ class BackendPlugin(DetectorBackendPluginBase[SharedState]):
         self.shared_state = SharedState()
         self.broadcast(sync=True)
 
+    @is_task
+    def update_sensor_id(self, *, sensor_id: int) -> None:
+        self.shared_state.sensor_id = sensor_id
+        self.broadcast(sync=True)
+
     @property
     def _client(self) -> Optional[a121.Client]:
         if self._replaying_client is not None:
@@ -186,7 +196,7 @@ class BackendPlugin(DetectorBackendPluginBase[SharedState]):
 
         self._detector_instance = Detector(
             client=self._client,
-            sensor_id=1,
+            sensor_id=self.shared_state.sensor_id,
             detector_config=self.shared_state.config,
         )
 
@@ -544,12 +554,14 @@ class ViewPlugin(DetectorViewPluginBase):
             "Start measurement",
             self.view_widget,
         )
+        self.start_button.setShortcut("space")
         self.start_button.clicked.connect(self._send_start_request)
         self.stop_button = QPushButton(
             qta.icon("fa5s.stop-circle", color=BUTTON_ICON_COLOR),
             "Stop",
             self.view_widget,
         )
+        self.stop_button.setShortcut("space")
         self.stop_button.clicked.connect(self._send_stop_request)
 
         self.defaults_button = QPushButton(
@@ -565,6 +577,16 @@ class ViewPlugin(DetectorViewPluginBase):
         button_group.layout().addWidget(self.defaults_button, 1, 0, 1, -1)
         self.view_layout.addWidget(button_group)
 
+        sensor_selection_group = utils.VerticalGroupBox(
+            "Sensor selection", parent=self.view_widget
+        )
+        self.sensor_id_pidget = pidgets.SensorIdParameterWidgetFactory(items=[]).create(
+            parent=sensor_selection_group
+        )
+        self.sensor_id_pidget.sig_parameter_changed.connect(self._on_sensor_id_update)
+        sensor_selection_group.layout().addWidget(self.sensor_id_pidget)
+        self.view_layout.addWidget(sensor_selection_group)
+
         self.config_editor = AttrsConfigEditor[DetectorConfig](
             title="Detector parameters",
             factory_mapping=self._get_pidget_mapping(),
@@ -588,6 +610,12 @@ class ViewPlugin(DetectorViewPluginBase):
                 suffix=" m",
                 decimals=3,
             ),
+            "step_length": pidgets.OptionalIntParameterWidgetFactory(
+                name_label_text="Step length",
+                checkbox_label_text="Override",
+                limits=(1, None),
+                init_set_value=24,
+            ),
             "detection_threshold": pidgets.FloatSliderParameterWidgetFactory(
                 name_label_text="Detection threshold",
                 decimals=2,
@@ -611,6 +639,7 @@ class ViewPlugin(DetectorViewPluginBase):
 
     def on_app_model_update(self, app_model: AppModel) -> None:
         state = app_model.backend_plugin_state
+        self.sensor_id_pidget.update_available_sensor_list(app_model._a121_server_info)
 
         if state is None:
             self.start_button.setEnabled(False)
@@ -619,6 +648,7 @@ class ViewPlugin(DetectorViewPluginBase):
 
             self.config_editor.set_data(None)
             self.config_editor.setEnabled(False)
+            self.sensor_id_pidget.set_parameter(None)
 
             return
 
@@ -628,6 +658,8 @@ class ViewPlugin(DetectorViewPluginBase):
 
         self.config_editor.setEnabled(app_model.plugin_state == PluginState.LOADED_IDLE)
         self.config_editor.set_data(state.config)
+        self.sensor_id_pidget.set_parameter(state.sensor_id)
+        self.sensor_id_pidget.setEnabled(app_model.plugin_state.is_steady)
 
         ready_for_session = (
             app_model.plugin_state == PluginState.LOADED_IDLE
@@ -663,6 +695,9 @@ class ViewPlugin(DetectorViewPluginBase):
     def _send_defaults_request(self) -> None:
         self.app_model.put_backend_plugin_task("restore_defaults")
 
+    def _on_sensor_id_update(self, sensor_id: int) -> None:
+        self.app_model.put_backend_plugin_task("update_sensor_id", {"sensor_id": sensor_id})
+
     # TODO: move to detector base (?)
     def teardown(self) -> None:
         self.view_layout.deleteLater()
