@@ -1,3 +1,6 @@
+# Copyright (c) Acconeer AB, 2022
+# All rights reserved
+
 from __future__ import annotations
 
 import logging
@@ -33,7 +36,7 @@ from ._processor import (
 log = logging.getLogger(__name__)
 
 
-class BackendPlugin(ProcessorBackendPluginBase[ProcessorConfig, Processor]):
+class BackendPlugin(ProcessorBackendPluginBase[ProcessorConfig, ProcessorResult]):
     @classmethod
     def get_processor_cls(cls) -> Type[Processor]:
         return Processor
